﻿// ***************************************************************************
//					(C) Copyright OMRON CORPORATION 2005-2007
//							All Rights Reserved
// ---------------------------------------------------------------------------
//							Procitem for FZ Series
// ***************************************************************************
// Filename    : FigureData.cpp
// Description : Procedure to operate figure data of processing unit
// ***************************************************************************

// *************************************
//         include files
// *************************************

#include	"StdAfx.h"
#include	<FZ-Include.h>
#include	"ItemDefs.h"

// *************************************
//         macro definition
// *************************************

// *************************************
//         external declaration
// *************************************

// *************************************
//         static variable
// *************************************

// *************************************
//         external variable
// *************************************

// *************************************
//         function reference
// *************************************

// ***************************************************************************
// title         : Procedure to set the format of figure data
// function name : int SetFigureType(ptrProcUnit, figureNo, type)
// parameters    : ProcUnit *ptrProcUnit;	Pointer to processing unit
//				   int      figureNo;		Figure number
//				   int      type;			Figure type
// return value  : Error code
//					NORMAL(0) : exit normally
//					else      : error exit
// ***************************************************************************

int CLASSNAME::SetFigureType(ProcUnit *ptrProcUnit, int figureNo, int type)
{
	int	unitNo;

	if (figureNo >= 0 && figureNo < 8) {
		unitNo = figureNo;
		figureNo = 0;
	} else if (figureNo == 8) {

		// get color data
		unitNo = 0;
		figureNo = 1;
	}

	if (ptrProcUnit->CheckInnerUnit(unitNo) != TRUE) {
		return -1;
	}

	ProcUnit *targetUnit = ptrProcUnit->GetInnerUnit(unitNo);
	return(ProcItem::SetFigureType(targetUnit, figureNo, type));
}

// ***************************************************************************
// title         : Procedure to get the format of figure data
// function name : int GetFigureType(ptrProcUnit, figureNo)
// parameters    : ProcUnit *ptrProcUnit;	Pointer to processing unit
//				   int      figureNo;		Figure number
// return value  : Returns the figure data type of the specified figure number.
//				   If failed to get, returns NULL.
// ***************************************************************************

int CLASSNAME::GetFigureType(ProcUnit *ptrProcUnit, int figureNo)
{
	int	unitNo;

	if (figureNo >= 0 && figureNo < 8) {
		unitNo = figureNo;
		figureNo = 0;
	} else if (figureNo == 8) {

		// get color data
		unitNo = 0;
		figureNo = 1;
	}

	if (ptrProcUnit->CheckInnerUnit(unitNo) != TRUE) {
		return -1;
	}

	ProcUnit *targetUnit = ptrProcUnit->GetInnerUnit(unitNo);
	return(ProcItem::GetFigureType(targetUnit, figureNo));
}

// ***************************************************************************
// title         : Procedure to set the figure data
// function name : int SetFigureData(ptrProcUnit, figureNo, ptrFigure)
// parameters    : ProcUnit *ptrProcUnit;	Pointer to processing unit
//				   int      figureNo;		Figure number
//				   FIG_HEADER *ptrFigure;	Pointer to setting figure data
// return value  : Error code
//					NORMAL(0) : exit normally
//					else      : error exit
// ***************************************************************************

int CLASSNAME::SetFigureData(ProcUnit *ptrProcUnit, int figureNo, FIG_HEADER *ptrFigure)
{
	int	unitNo;

	if (figureNo >= 0 && figureNo < 8) {
		unitNo = figureNo;
		figureNo = 0;
	} else if (figureNo == 8) {

		// get color data
		unitNo = 0;
		figureNo = 1;
	}

	if (ptrProcUnit->CheckInnerUnit(unitNo) != TRUE) {
		return -1;
	}

	ProcUnit *targetUnit = ptrProcUnit->GetInnerUnit(unitNo);

//	return(ProcItem::SetFigureData(targetUnit, figureNo, ptrFigure));

	int res = targetUnit->SetFigureData(figureNo, ptrFigure, 1);
	return res;
}

// ***************************************************************************
// title         : Procedure to add a figure 
// function name : int AddFigureData(ptrProcUnit, figureNo, type, data)
// parameters    : ProcUnit *ptrProcUnit;	Pointer to processing unit
//				   int      figureNo;		Figure number
//				   FIG_TYPE *type;			Pointer to the figure data to be added
//				   void     *data;			Pointer to the figure information to be added
// return value  : Error code
//					NORMAL(0) : exit normally
//					else      : error exit
// ***************************************************************************

int CLASSNAME::AddFigureData(ProcUnit *ptrProcUnit, int figureNo, FIG_TYPE *type, void *data)
{
	int	unitNo;

	if (figureNo >= 0 && figureNo < 8) {
		unitNo = figureNo;
		figureNo = 0;
	} else if (figureNo == 8) {

		// get color data
		unitNo = 0;
		figureNo = 1;
	}

	if (ptrProcUnit->CheckInnerUnit(unitNo) != TRUE) {
		return -1;
	}

	ProcUnit *targetUnit = ptrProcUnit->GetInnerUnit(unitNo);
	return(ProcItem::AddFigureData(targetUnit, figureNo, type, data));
//	int res = targetUnit->AddFigureData(figureNo, type, data);
//	return res;
}

// ***************************************************************************
// title         : Procedure to get the figure data 
// function name : int GetFigureData(ProcUnit *ptrProcUnit, int figureNo)
// parameters    : ProcUnit *ptrProcUnit;	Pointer to processing unit
//				   int      figureNo;		Figure number
// return value  : Returns the pointer to the figure data of the specified figure number.
//				   If failed to get, returns NULL.
// ***************************************************************************

FIG_HEADER *CLASSNAME::GetFigureData(ProcUnit *ptrProcUnit, int figureNo)
{
	int	unitNo;

	if (figureNo >= 0 && figureNo < 8) {
		unitNo = figureNo;
		figureNo = 0;
	} else if (figureNo == 8) {

		// get color data
		unitNo = 0;
		figureNo = 1;
	}

	if (ptrProcUnit->CheckInnerUnit(unitNo) != TRUE) {
		return NULL;
	}

	ProcUnit *targetUnit = ptrProcUnit->GetInnerUnit(unitNo);
	return(ProcItem::GetFigureData(targetUnit, figureNo));

//	FIG_HEADER *res = targetUnit->GetFigureData(figureNo);
//	return res;
}

