﻿// ***************************************************************************
//					(C) Copyright OMRON CORPORATION 2005-2007
//							All Rights Reserved
// ---------------------------------------------------------------------------
//							Procitem for FZ Series
// ***************************************************************************
// Filename    : MeasureDisp.cpp
// Description : Procedure of displaying measurement result
// ***************************************************************************

// *************************************
//         include files
// *************************************

#include	"StdAfx.h"
#include	<FZ-Include.h>
#include	"ItemDefs.h"

// *************************************
//         macro definition
// *************************************

// *************************************
//         external declaration
// *************************************

// *************************************
//         static variable
// *************************************

// *************************************
//         external variable
// *************************************

// *************************************
//         function reference
// *************************************

// ***************************************************************************
// title         : Display result (Image)
// function name : int MeasureDispI(ptrProcUnit, subNo, ptrImageWindow)
// parameters    : ProcUnit    *ptrProcUnit;	Pointer to processing unit
//				   int         subNo;			Sub number of display
//				   ImageWindow *ptrImageWindow;	Pointer to image window
// return value  : Error code
//					NORMAL(0) : exit normally
//					else      : error exit
// ***************************************************************************

int CLASSNAME::MeasureDispI(ProcUnit *ptrProcUnit, int subNo, ImageWindow *ptrImageWindow)
{

	if (subNo > 0 && subNo <= 8) {
		ProcUnit *targetUnit = ptrProcUnit->GetInnerUnit(subNo - 1);
		targetUnit->MeasureDispI(1, ptrImageWindow);
	} else {
		IMAGE		*image = ptrProcUnit->GetMeasureImage(0);
		ptrImageWindow->ImageDisp(image);
	}

	return(NORMAL);
}

// ***************************************************************************
// title         : Display result (Graphic)
// function name : int MeasureDispG(ptrProcUnit, subNo, ptrImageWindow)
// parameters    : ProcUnit    *ptrProcUnit;	Pointer to processing unit
//				   int         subNo;			Sub number of display
//				   ImageWindow *ptrImageWindow;	Pointer to image window
// return value  : Error code
//					NORMAL(0) : exit normally
//					else      : error exit
// ***************************************************************************

int CLASSNAME::MeasureDispG(ProcUnit *ptrProcUnit, int subNo, ImageWindow *ptrImageWindow)
{
	if (subNo == 0) {

		// display all regions
		for (int i = 0; i < 8; i++) {
			ProcUnit *targetUnit = ptrProcUnit->GetInnerUnit(i);
			targetUnit->MeasureDispG(0, ptrImageWindow);
		}
	}

	return(NORMAL);
}

// ***************************************************************************
// title         : Display result (Text)
// function name : int MeasureDispT(ptrProcUnit, subNo, ptrTextWindow)
// parameters    : ProcUnit     *ptrProcUnit;	Pointer to processing unit
//					int         subNo;			Sub number of display
//					TextWindow  *ptrTextWindow;	Pointer to text window
// return value  : Error code
//					NORMAL(0) : exit normally
//					else      : error exit
// ***************************************************************************

int CLASSNAME::MeasureDispT(ProcUnit *ptrProcUnit, int subNo, TextWindow *ptrTextWindow)
{
	MEASUREDATA *ptrMeasureData = ptrProcUnit->GetMeasureData();

	int nJudge = ptrProcUnit->GetUnitJudge();

	ptrTextWindow->DrawJudgeText(nJudge);

	if (nJudge != JUDGE_NC) {

		ptrProcUnit->SetMeasureProcMask(1);

		for (int i = 0; i < 8; i++) {
			ProcUnit *targetUnit = ptrProcUnit->GetInnerUnit(i);
			ANYTYPE any;
			targetUnit->GetUnitData(_T("positionX"), &any);
			ptrMeasureData->coPos[i].x = any.dval;
			
			targetUnit->GetUnitData(_T("positionY"), &any);
			ptrMeasureData->coPos[i].y = any.dval;	
			
			nJudge = targetUnit->GetUnitJudge();
			ptrTextWindow->DrawTextW(nJudge, TRUE, _T("Edge %d  x:%.2f, y:%.2f"), i, ptrMeasureData->coPos[i].x, ptrMeasureData->coPos[i].y);
		}
		ptrProcUnit->SetMeasureProcMask(0);
	}

	return(NORMAL);
}

