﻿// ***************************************************************************
//					(C) Copyright OMRON CORPORATION 2005-2007
//							All Rights Reserved
// ---------------------------------------------------------------------------
//							Procitem for FZ Series
// ***************************************************************************
// Filename    : UnitData.cpp
// Description : Procesure to set / get processing unit data
// ***************************************************************************

// *************************************
//         include files
// *************************************

#include	"StdAfx.h"
#include	<FZ-Include.h>
#include	"ItemDefs.h"

// *************************************
//         macro definition
// *************************************

// *************************************
//         external declaration
// *************************************

// *************************************
//         static variable
// *************************************

// 0: total judge
// 200 - 399 : region 0
// 400 - 599 : region 1
// 600 - 799 : region 2
// 800 - 999 : region 3
// 1000 - 1199 : region 4
// 1200 - 1399 : region 5
// 1400 - 1599 : region 6
// 1600 - 1799 : region 7
// ...
// 5000 - : reference = region 0, set = all region
// 5001 : <- 101(outputCoordinate)
// 5002 : <- 102(calibration)
// 5003 : <- 103(overallJudge)

/*
typedef struct {
	int		no;
	TCHAR	*ident;
	double	low;
	double	high;
} TABLE;
static const TABLE nameTable[] = {
	{  0, _T("judge"), 0, 0},
	{  0, _T("JG"), 0, 0},
	{  5, _T("positionX"), 0, 0},
	{  5, _T("X"), 0, 0},
	{  6, _T("positionY"), 0, 0},
	{  6, _T("Y"), 0, 0},
	{  7, _T("referenceX"), 0, 0},
	{  7, _T("SX"), 0, 0},
	{  8, _T("referenceY"), 0, 0},
	{  8, _T("SY"), 0, 0},

	{101, _T("outputCoordinate"), 0, 1},
	{102, _T("calibration"), 0, 1},
	{103, _T("overallJudge"), 0, 1},		//2007/02/19 F.K ADD

	{120, _T("colorSpecification"), 0, 1}, 
	{121, _T("colorR"), 0, PXR_MAX},
	{122, _T("colorG"), 0, PXR_MAX},
	{123, _T("colorB"), 0, PXR_MAX},
	{124, _T("colorDevR"), 0, 127},
	{125, _T("colorDevG"), 0, 127},
	{126, _T("colorDevB"), 0, 127},
	{127, _T("detectionMode"), 0, 1},
	{128, _T("colEmphasisDisp"), 0, 1},	// 2007/02/19 F.K ADD
	{129, _T("referencePosX"), VGA_MIN, VGA_MAX},
	{130, _T("referencePosY"), VGA_MIN, VGA_MAX},
	{131, _T("edgeNo"), 0, 99},
	{132, _T("edgeLevel"), 0, 100},
	{133, _T("noiseLevel"), 0, 442},
	{134, _T("noiseWidth"), VGA_MIN, VGA_MAX},
	{135, _T("colorLevel"), 0, 442},
	{136, _T("upperX"), X_MIN, X_MAX},
	{137, _T("lowerX"), X_MIN, X_MAX},
	{138, _T("upperY"), Y_MIN, Y_MAX},
	{139, _T("lowerY"), Y_MIN, Y_MAX},
	{140, _T("monoDetectMode"), 0, 1},		// モノクロエッジ検出モード
	{141, _T("edgeLevelAbs"), 0, 442},		// エッジレベル絶対値
	{142, _T("edgeLevelKind"), 0, 1},
	{143, _T("counterclockwise"), 0, 1},	// 時計回り/反時計回り区分
	
	{150, _T("colorArea"), -1, -1},
	{151, _T("colorDevArea"), -1, -1},
	{152, _T("autoReference"), -1, -1},
	{153, _T("graphExpand"), -1, -1},
	{154, _T("graphBackground"), -1, -1},
	{155, _T("graphMove"), -1, -1},
	{156, _T("graphOffset"), -1, -1},
	{157, _T("graphOffsetMax"), -1, -1},

	{5000,  _T("autoMeasure"),-1,-1},
	{6000, _T("cameraNo"), -1, -1},
	{6001, _T("cameraConnect"), -1, -1},
	{6002, _T("cameraColor"), -1, -1},
	{6003, _T("cameraWidth"), -1, -1},
	{6004, _T("cameraHeight"), -1, -1},
	{6005, _T("cameraPixel"), -1, -1},
	{6006, _T("cameraModel"), -1, -1},
	{6007, _T("cameraIF"), -1, -1},

	{9000, _T("measureImageNo"), 0, 4},

	{ -1, 0, 0, 0}
};
*/

static const TCHAR *regionPrefix[] = {
	_T("R0"),
	_T("R1"),
	_T("R2"),
	_T("R3"),
	_T("R4"),
	_T("R5"),
	_T("R6"),
	_T("R7")
};



// *************************************
//         external variable
// *************************************

// *************************************
//         function reference
// *************************************

// ***************************************************************************
// title         : set processing unit data by number
// function name : int SetUnitData(ptrProcUnit, dataNo, data)
// parameters    : ProcUnit *ptrProcUnit;	Pointer to processing unit
//				   int      dataNo;			Data number.
//				   ANYTYPE  *data;			Setting data
// return value  : Error code
//					NORMAL(0) : exit normally
//					else      : error exit
// ***************************************************************************

int CLASSNAME::SetUnitData(ProcUnit *ptrProcUnit, int dataNo, ANYTYPE *data)
{
	int	res;

	if (dataNo >= 200 && dataNo < 1800) {
	    int unitNo = dataNo / 200 - 1;
	    dataNo = dataNo - (200 * unitNo) - 200;

		ProcUnit *targetUnit = ptrProcUnit->GetInnerUnit(unitNo);
		res = targetUnit->SetUnitData(dataNo, data);
	} else if (dataNo >= 5000) {

		for (int i = 0; i < 7; i++) {

			ProcUnit *targetUnit = ptrProcUnit->GetInnerUnit(i);
			res = targetUnit->SetUnitData(dataNo, data);
			if (res != NORMAL) {
				break;
			}
		}
	}
	return(NORMAL);
}

// ***************************************************************************
// title         : set processing unit data by number
// function name : int SetUnitData(ptrProcUnit, dataIdent, data)
// parameters    : ProcUnit *ptrProcUnit;	Pointer to processing unit
//				   TCHAR    *dataIdent;		Data identification name
//				   ANYTYPE  *data;			Setting data
// return value  : Error code
//					NORMAL(0) : exit normally
//					else      : error exit
// ***************************************************************************

int CLASSNAME::SetUnitData(ProcUnit *ptrProcUnit, TCHAR *dataIdent, ANYTYPE *data)
{
	int	res;

	if (_tcslen(dataIdent) > 2) {

		for (int i = 0; i < 8; i++) {
			if (_tcsncmp(dataIdent, regionPrefix[i], 2) == 0) {
							
				ProcUnit *targetUnit = ptrProcUnit->GetInnerUnit(i);
				res = targetUnit->SetUnitData(dataIdent+2, data);
				return res;
			}
		}
	}

	for (int i = 0; i < 7; i++) {

		ProcUnit *targetUnit = ptrProcUnit->GetInnerUnit(i);
		res = targetUnit->SetUnitData(dataIdent, data);
		if (res != NORMAL) {
			break;
		}
	}
	return(res);
}

// ***************************************************************************
// title         : get processing unit data by number
// function name : int GetUnitData(ptrProcUnit, dataNo, data)
// parameters    : ProcUnit *ptrProcUnit;	Pointer to processing unit
//				   int      dataNo;			Data number.
//				   ANYTYPE  *data;			Getting data
// return value  : Error code
//					NORMAL(0) : exit normally
//					else      : error exit
// ***************************************************************************

int CLASSNAME::GetUnitData(ProcUnit *ptrProcUnit, int dataNo, ANYTYPE *data)
{
	int	res = NORMAL;

	if (dataNo == 0) {
		data->SetVal(ptrProcUnit->GetUnitJudge());

	} else if (dataNo >= 200 && dataNo < 1800) {
	    int unitNo = dataNo / 200 - 1;
	    dataNo = dataNo - (200 * unitNo) - 200;

		ProcUnit *targetUnit = ptrProcUnit->GetInnerUnit(unitNo);
		res = targetUnit->GetUnitData(dataNo, data);

	} else if (dataNo >= 5000) {

		ProcUnit *targetUnit = ptrProcUnit->GetInnerUnit(0);
		res = targetUnit->GetUnitData(dataNo, data);
	}
	return(res);
}

// ***************************************************************************
// title         : get processing unit data by number
// function name : int GetUnitData(ptrProcUnit, dataIdent, data)
// parameters    : ProcUnit *ptrProcUnit;	Pointer to processing unit
//				   TCHAR    *dataIdent;		Data identification name
//				   ANYTYPE  *data;			Getting data
// return value  : Error code
//					NORMAL(0) : exit normally
//					else      : error exit
// ***************************************************************************

int CLASSNAME::GetUnitData(ProcUnit *ptrProcUnit, TCHAR *dataIdent, ANYTYPE *data)
{
	int	res = NORMAL;

	if (_tcscmp(dataIdent, _T("JG")) == 0) {

		data->SetVal(ptrProcUnit->GetUnitJudge());

	} else if (_tcslen(dataIdent) > 2) {

		for (int i = 0; i < 8; i++) {
			if (_tcsncmp(dataIdent, regionPrefix[i], 2) == 0) {
							
				ProcUnit *targetUnit = ptrProcUnit->GetInnerUnit(i);
				res = targetUnit->GetUnitData(dataIdent+2, data);
				return res;
			}
		}
	}

	ProcUnit *targetUnit = ptrProcUnit->GetInnerUnit(0);
	res = targetUnit->GetUnitData(dataIdent, data);

	return(res);
}

